==> CustomGS-1.0.tar.gz: CustomGS/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Custom Global Settings
# Author: Rolf Tjassens
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2011 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/customgs
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

/** 
 * Uninstall module
 */

$this->RemovePermission('Custom Global Settings - Manage');
$this->RemovePermission('Custom Global Settings - Settings');
		
$this->RemovePreference('input_custom_modulename');
		
$number_checkboxes = 7;
$current = 1;
	while ($current <= $number_checkboxes) {
		$this->RemovePreference('input_checkbox_'.$current);
		$this->RemovePreference('input_title_checkbox_'.$current);
		$this->RemovePreference('input_help_checkbox_'.$current);
		$current++;
		}
				
$number_textfields = 5;
$current = 1;
	while ($current <= $number_textfields) {
		$this->RemovePreference('input_textfield_'.$current);
		$this->RemovePreference('input_title_textfield_'.$current);
		$this->RemovePreference('input_help_textfield_'.$current);
		$current++;
		}

?>

==> CustomGS-1.6.tar.gz: CustomGS/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Custom Global Settings
# Author: Rolf Tjassens, Jos
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2011 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/customgs
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

/** 
 * Uninstall module
 */
$db = $gCms->GetDb();

// remove the database tables
$dict = NewDataDictionary( $db );
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_customgs" );
$dict->ExecuteSQLArray($sqlarray);

// remove the permissions
$this->RemovePermission('Custom Global Settings - Use');
$this->RemovePermission('Custom Global Settings - Manage');
		
// remove all preferences
$this->RemovePreference();

// remove the event
$this->RemoveEvent('OnSettingChange');

?>
